/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.bootstrap.command.io;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.util.Optional;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

class StandardBootstrapArgumentParserTest {
    private static final String CLUSTER_STATUS_ARGUMENT = "cluster-status";

    private StandardBootstrapArgumentParser parser;

    @BeforeEach
    void setParser() {
        parser = new StandardBootstrapArgumentParser();
    }

    @Test
    void testGetBootstrapArgumentNull() {
        final Optional<BootstrapArgument> bootstrapArgumentFound = parser.getBootstrapArgument(null);

        assertTrue(bootstrapArgumentFound.isEmpty());
    }

    @Test
    void testGetBootstrapArgumentClusterStatus() {
        final Optional<BootstrapArgument> bootstrapArgumentFound = parser.getBootstrapArgument(new String[]{CLUSTER_STATUS_ARGUMENT});

        assertTrue(bootstrapArgumentFound.isPresent());
        assertEquals(BootstrapArgument.CLUSTER_STATUS, bootstrapArgumentFound.get());
    }
}
