/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.controller.status.history.questdb;

import java.time.Instant;
import java.util.Objects;

final class CapturedStatus<T> {
    private final T status;
    private final Instant captured;

    CapturedStatus(final T status, final Instant captured) {
        this.status = status;
        this.captured = captured;
    }

    T getStatus() {
        return status;
    }

    Instant getCaptured() {
        return captured;
    }

    @Override
    public boolean equals(final Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        final CapturedStatus<?> that = (CapturedStatus<?>) o;
        return Objects.equals(status, that.status) && Objects.equals(captured, that.captured);
    }

    @Override
    public int hashCode() {
        return Objects.hash(status, captured);
    }
}
