/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.web.api.dto;

import io.swagger.v3.oas.annotations.media.Schema;
import org.apache.nifi.web.api.entity.TenantEntity;

import jakarta.xml.bind.annotation.XmlType;
import java.util.Set;

/**
 * Details for the access configuration.
 */
@XmlType(name = "accessPolicy")
public class AccessPolicyDTO  extends AccessPolicySummaryDTO {

    private Set<TenantEntity> users;
    private Set<TenantEntity> userGroups;

    /**
     * @return The set of user IDs associated with this access policy.
     */
    @Schema(description = "The set of user IDs associated with this access policy.")
    public Set<TenantEntity> getUsers() {
        return users;
    }

    public void setUsers(Set<TenantEntity> users) {
        this.users = users;
    }

    /**
     * @return The set of user group IDs associated with this access policy.
     */
    @Schema(description = "The set of user group IDs associated with this access policy.")
    public Set<TenantEntity> getUserGroups() {
        return userGroups;
    }

    public void setUserGroups(Set<TenantEntity> userGroups) {
        this.userGroups = userGroups;
    }
}
