/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.controller.service;

import org.apache.nifi.flow.Bundle;
import org.apache.nifi.flow.ControllerServiceAPI;

import java.util.Map;

public interface ControllerServiceApiLookup {

    /**
     * Returns the required service APIs for any property descriptors in the component specified by the
     * given type and bundle. The key of the returned Map is the name of the PropertyDescriptor.
     *
     * @param type a component type
     * @param bundle a component bundle
     * @return the required services APIs for the component's property descriptors, or empty Map if no compatible
     *             bundle could be found, or if the component doesn't require any service APIs
     */
    Map<String, ControllerServiceAPI> getRequiredServiceApis(String type, Bundle bundle);

}
