/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.runtime;

import org.apache.nifi.NiFiServer;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertThrows;
import static org.junit.jupiter.api.Assertions.assertTrue;

@ExtendWith(MockitoExtension.class)
class ManagementServerProviderTest {
    private static final String ADDRESS_WITHOUT_PORT = "127.0.0.1";

    @Mock
    private NiFiServer server;

    @Test
    void testGetManagementServer() {
        final ManagementServer managementServer = ManagementServerProvider.getManagementServer(server);

        assertNotNull(managementServer);
    }

    @Test
    void testGetManagementServerPropertyNotValid() {
        System.setProperty(ManagementServerProvider.MANAGEMENT_SERVER_ADDRESS, ADDRESS_WITHOUT_PORT);
        try {
            final IllegalStateException exception = assertThrows(IllegalStateException.class, () -> ManagementServerProvider.getManagementServer(server));

            assertTrue(exception.getMessage().contains(ManagementServerProvider.MANAGEMENT_SERVER_ADDRESS));
        } finally {
            System.clearProperty(ManagementServerProvider.MANAGEMENT_SERVER_ADDRESS);
        }
    }
}
